@@ -2,13 +2,13 @@ package LCFG::Build::VCS::CVS;  # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: CVS.pm.in 23958 2013-10-11 12:45:38Z squinney@INF.ED.AC.UK $
+# $Id: CVS.pm.in 29257 2015-11-12 15:42:14Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-VCS/lib/LCFG/Build/VCS/CVS.pm.in,v $
-# $Revision: 23958 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_1/lib/LCFG/Build/VCS/CVS.pm.in $
-# $Date: 2013-10-11 13:45:38 +0100 (Fri, 11 Oct 2013) $
+# $Revision: 29257 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_2/lib/LCFG/Build/VCS/CVS.pm.in $
+# $Date: 2015-11-12 15:42:14 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 use Cwd            ();
 use File::Find     ();
@@ -98,7 +98,7 @@ sub genchangelog {
         $self->run_cmd( 'add', $logfile );
     }
 
-    my $cmd = '/usr/bin/cvs2cl --hide-filenames --accum --file ' . $logfile;
+    my $cmd = 'cvs2cl --hide-filenames --accum --file ' . $logfile;
 
     if ( $self->quiet ) {
         $cmd .= ' --global-opts \'-Q\'';
@@ -377,7 +377,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::VCS::CVS version 0.2.1
+    This documentation refers to LCFG::Build::VCS::CVS version 0.2.2
 
 =head1 SYNOPSIS
 
