@@ -2,13 +2,13 @@ package LCFG::Build::VCS::SVN; # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: SVN.pm.in 23923 2013-10-08 16:17:56Z squinney@INF.ED.AC.UK $
+# $Id: SVN.pm.in 29257 2015-11-12 15:42:14Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-VCS/lib/LCFG/Build/VCS/SVN.pm.in,v $
-# $Revision: 23923 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_1/lib/LCFG/Build/VCS/SVN.pm.in $
-# $Date: 2013-10-08 17:17:56 +0100 (Tue, 08 Oct 2013) $
+# $Revision: 29257 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-VCS/LCFG_Build_VCS_0_2_2/lib/LCFG/Build/VCS/SVN.pm.in $
+# $Date: 2015-11-12 15:42:14 +0000 (Thu, 12 Nov 2015) $
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 use File::Path ();
 use File::Spec ();
@@ -274,7 +274,7 @@ sub genchangelog {
     # MUST do an update beforehand otherwise some logs get missed.
     $self->run_cmd( 'update', $dir );
 
-    my @cmd = ( '/usr/bin/svn2cl', '--output', $logfile, $dir );
+    my @cmd = ( 'svn2cl', '--output', $logfile, $dir );
     if ( $self->dryrun ) {
         print "Dry-run: @cmd\n";
     }
@@ -375,7 +375,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::VCS::SVN version 0.2.1
+    This documentation refers to LCFG::Build::VCS::SVN version 0.2.2
 
 =head1 SYNOPSIS
 
